-- Marx T.V. Tennis Simulator v0.2
-- Programmed by Sly DC (November 21, 2012)

-- Button configuration:
-- "W" and "S" = Player 1
-- "UP" and "DOWN" = Player 2
-- "ESCAPE" = Quit/Exit game
-- "P" = Pause
-- "F1" = Full/Window mode
-- "1" = Human player or AI
-- "2" = Human player or AI
-- "F4" = Reset game
-- "F5" = Green model
-- "F6" = Red Wine model
-- "F7" = Black model


local bing_sound =love.audio.newSource("bell.wav","static")
--local bop_sound =love.audio.newSource("paddle.wav","static")
local bzz_sound = love.audio.newSource("motor.ogg", "stream")

function love.load()                                                                                
	love.mouse.setVisible(false)
    screen_width = 800
    screen_height = 600
    love.graphics.setCaption('Marx T.V. Tennis (1974) Simulator (v0.2)')                     -- text display in window mode
    love.graphics.setMode(screen_width, screen_height, false)                                -- put "true" for booting full screen
    bg = love.graphics.newImage('background.png')       -- Green background
    redbg = love.graphics.newImage('redback.png')	    -- Red Wine background
    blackbg = love.graphics.newImage('blackback.png')   -- Black background
    ovl = love.graphics.newImage('overlay.png')         -- Green overlay
    ovl2 = love.graphics.newImage('overlay2.png')       -- Red Wine overlay
    ovl3 = love.graphics.newImage('overlay3.png')       -- Black overlay	
    g1 = love.graphics.newImage('goaler1.png')
    g2 = love.graphics.newImage('goaler2.png')
    g3 = love.graphics.newImage('goaler3.png')
    g4 = love.graphics.newImage('goaler4.png')
    puck = love.graphics.newImage('puck.png')
    puck2 = love.graphics.newImage("puck2.png")         -- White puck for Red/Black
    win = love.graphics.newImage('winner.png')          -- Green Winner indicator
    win2 = love.graphics.newImage("winner2.png")	    -- Red Wine/Black Winner indicator
    state = 'play'
	ai1 = false
    ai2 = false
    greenmodel = true
	redmodel = false
	blackmodel = false
    gameover = false
    paddle = {}    
	paddle[1] = {}
	paddle[1].x = 134
	paddle[1].y = 313                                                                            
	paddle[1].score = 0
--  paddle[1].speed = 150
	paddle[2] = {}
	paddle[2].x = 592
	paddle[2].y = 313                                                                             
	paddle[2].score = 0
--	paddle[2].speed = 200
	ball = {}
	ball.x = 392
	ball.y = 313
	ball.dx = -1
	ball.dy = 0.3
	speed = 200
 	font = love.graphics.newFont("arial.ttf", 16)
 	love.graphics.setFont(font)     
    bzz_sound:setLooping(true)	
	bzz_sound:setVolume(0.5)
	bzz_sound:play()
end

function love.update(dt)
    if state ~= 'play' then return end
	--player 1 - keyboard
	if love.keyboard.isDown("s") then
		paddle[1].y = paddle[1].y + speed*dt
		clamp_paddle(1)
	elseif love.keyboard.isDown("w") then
		paddle[1].y = paddle[1].y - speed*dt
		clamp_paddle(1)
	end
	-- player 1 AI
	if ai1 then
	    if ball.x < 399 and paddle[1].y < ball.y then paddle[1].y = paddle[1].y + speed*dt/1.5 end
	    if ball.x < 399 and paddle[1].y > ball.y then paddle[1].y = paddle[1].y - speed*dt/1.5 end
    end
	--player 2 - keyboard
	if love.keyboard.isDown("down") then
		paddle[2].y = paddle[2].y + speed*dt
		clamp_paddle(2)
	elseif love.keyboard.isDown("up") then
		paddle[2].y = paddle[2].y - speed*dt
		clamp_paddle(2)
	end
	-- player 2 AI
	if ai2 then
	    if ball.x > 400 and paddle[2].y < ball.y then paddle[2].y = paddle[2].y + speed*dt/1.5 end
	    if ball.x > 400 and paddle[2].y > ball.y then paddle[2].y = paddle[2].y - speed*dt/1.5 end
    end
	ball.x = ball.x+ball.dx*speed*dt
	ball.y = ball.y+ball.dy*speed*dt
	clamp_ball()
	ball_paddle(1)
	ball_paddle(2) 
end

function clamp_paddle(n)
	paddle[n].y = math.min(432, math.max(153, paddle[n].y))
end

function clamp_ball()
	if ball.x < 198 then
      bing_sound:stop()                                                                             
      bing_sound:play()
		ball.x = 198
		ball.dx = math.abs(ball.dx)
		paddle[2].score = paddle[2].score + 1                                                   
	end
	if ball.x > 585 then
      bing_sound:stop()
      bing_sound:play()
		ball.x = 585
		ball.dx = -math.abs(ball.dx)                                                            
		paddle[1].score = paddle[1].score + 1
	end
	if ball.y < 153 then
--      bing_sound:stop()                      -- implant a "thud" sound later?
--      bing_sound:play()                      -- implant a "thud" sound later?
		ball.y = 153
		ball.dy = math.abs(ball.dy)
	end
	if ball.y > 472 then  --445
--      bing_sound:stop()                      -- implant a "thud" sound later?                     
--      bing_sound:play()                      -- implant a "thud" sound later?
		ball.y = 472
		ball.dy = -math.abs(ball.dy)
	end                                                                                          
end

function ball_paddle(n)
	local x = n == 1 and 196 or 577
	if ball.x+5 < x or ball.x-5 > x+10 then return end
	if ball.y+5 < paddle[n].y-25 or ball.y-5 > paddle[n].y+25 then return end                     
	if ball.y < paddle[n].y-25 then
		if ball.x < x then
			local dist = (ball.x-x)^2+(ball.y-paddle[n].y+25)^2
			if dist > 25 then return end
		else
			local dist = (ball.x-x-10)^2+(ball.y-paddle[n].y+25)^2
			if dist > 25 then return end
		end
	elseif ball.y > paddle[n].y+25 then
		if ball.x < x then                                                                      
			local dist = (ball.x-x)^2+(ball.y-paddle[n].y-25)^2
			if dist > 25 then return end
		else
			local dist = (ball.x-x-10)^2+(ball.y-paddle[n].y-25)^2                           
			if dist > 25 then return end
		end
	end
	--we collide
	local dir = n == 1 and 1 or -1
--      bop_sound:stop()                        -- implant a "thud" sound later?                    
--      bop_sound:play()                        -- implant a "thud" sound later?
	local angle = math.atan2(ball.y-paddle[n].y, ball.x-x-10)
	ball.dx = dir
	ball.dy = math.sin(angle)
end

function love.keypressed(key)
	if key == "escape" then love.event.quit() end                                                                                          
    if key == "f1" then                                                                     -- toggles full screen or window mode
        love.graphics.toggleFullscreen()
        isFullscreen = not isFullscreen
    end
    if key == 'p' then                                                                       -- pause game
        if state == 'play' then 
		    state = 'pause'
            love.audio.pause(bzz_sound)
            else state = 'play' 
            love.audio.resume(bzz_sound)
        end
    end
	if key =="1" then ai1 = not ai1 end
	if key =="2" then ai2 = not ai2 end
	if key == "f4" then reset_game() end  
	if key == "f5" then
	    greenmodel = true  
		redmodel = false
		blackmodel = false
	end	
	if key == "f6" then
        redmodel = true 
		greenmodel = false
		blackmodel = false
    end		
	if key == "f7" then
	    blackmodel = true 
		greenmodel = false
		redmodel = false
    end		
end

function reset_game()
	state = 'play'
	paddle[1].score = 0
	paddle[2].score = 0
	ball.x = 392
	ball.y = 313
    bzz_sound:setLooping(true)	
	bzz_sound:setVolume(0.5)
	bzz_sound:play()
end

function love.draw()                                                                                
    if greenmodel == true then draw_green() end
    if redmodel == true then draw_red() end
	if blackmodel == true then draw_black() end
end

function draw_green()                                                                                
    love.graphics.draw(bg, 0, 0)
    love.graphics.setColor(51,121,51)
    if paddle[1].score <= 9 then 
    love.graphics.setColor(51,121,51)
    love.graphics.print(paddle[1].score, 240, 68)                                              
	end
    if paddle[1].score >= 10 then 
    love.graphics.setColor(51,121,51)
    love.graphics.print(paddle[1].score, 236, 68)                                              
	end
    if paddle[2].score <= 9 then 
    love.graphics.setColor(51,121,51)
    love.graphics.print(paddle[2].score, 549, 68)       
    end
    if paddle[2].score >= 10 then 
    love.graphics.setColor(51,121,51)
    love.graphics.print(paddle[2].score, 545, 68)      
    end
    love.graphics.setColor(255,255,255,255)
    love.graphics.draw( g1, paddle[1].x, paddle[1].y)
    love.graphics.draw( g2, paddle[2].x, paddle[2].y)
    love.graphics.draw( puck, ball.x, ball.y)
    love.graphics.setColor(255,255,255,255)                                                       
    love.graphics.draw(ovl, 0, 98 )
	if paddle[1].score == 11 then love.graphics.draw(win, 323, 64) end
    if paddle[2].score == 11 then love.graphics.draw(win, 423, 64) end	  
    if paddle[1].score >= 11 then 
	    paddle[1].score = 11     
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end	
    if paddle[2].score >= 11 then 
	    paddle[2].score = 11 
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end	
end

function draw_red()
    love.graphics.draw(redbg, 0, 0)
    if paddle[1].score <= 9 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[1].score, 240, 68)                                              
	end
    if paddle[1].score >= 10 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[1].score, 236, 68)                                              
	end
    if paddle[2].score <= 9 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[2].score, 549, 68)       
    end
    if paddle[2].score >= 10 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[2].score, 545, 68)      
    end
    love.graphics.setColor(255,255,255,255)
    love.graphics.draw( g3, paddle[1].x, paddle[1].y)
    love.graphics.draw( g4, paddle[2].x, paddle[2].y)
    love.graphics.draw( puck2, ball.x, ball.y)
    love.graphics.setColor(255,255,255,255)                                                       
    love.graphics.draw(ovl2, 0, 98 )
	if paddle[1].score == 11 then love.graphics.draw(win, 323, 64) end
    if paddle[2].score == 11 then love.graphics.draw(win, 423, 64) end	  
    if paddle[1].score >= 11 then 
	    paddle[1].score = 11     
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end	
    if paddle[2].score >= 11 then 
	    paddle[2].score = 11 
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end	
end

function draw_black()
    love.graphics.draw(blackbg, 0, 0)
    if paddle[1].score <= 9 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[1].score, 240, 68)                                              
	end
    if paddle[1].score >= 10 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[1].score, 236, 68)                                              
	end
    if paddle[2].score <= 9 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[2].score, 549, 68)       
    end
    if paddle[2].score >= 10 then 
    love.graphics.setColor(255,26,26)                         
    love.graphics.print(paddle[2].score, 545, 68)      
    end
    love.graphics.setColor(255,255,255,255)
    love.graphics.draw( g3, paddle[1].x, paddle[1].y)
    love.graphics.draw( g4, paddle[2].x, paddle[2].y)
    love.graphics.draw( puck2, ball.x, ball.y)
    love.graphics.setColor(255,255,255,255)                                                       
    love.graphics.draw(ovl3, 0, 98 )
	if paddle[1].score == 11 then love.graphics.draw(win, 323, 64) end
    if paddle[2].score == 11 then love.graphics.draw(win, 423, 64) end	  
    if paddle[1].score >= 11 then 
	    paddle[1].score = 11     
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end	
    if paddle[2].score >= 11 then 
	    paddle[2].score = 11 
        love.audio.pause(bzz_sound)
	    state = 'pause'
	end		
end